initialPrevious property
T?
initialPrevious
final
The initial previous value to use for the first emission.
If null, the first emission will have null as the previous value.
Implementation
final T? initialPrevious;